PALM-meteo: palmmeteo_stdplugins.meteo.RequiresMeteoPluginMixin Class Reference

PALM-meteo

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
palmmeteo_stdplugins.meteo.RequiresMeteoPluginMixin Class Reference
Inheritance diagram for palmmeteo_stdplugins.meteo.RequiresMeteoPluginMixin:
[legend]
Collaboration diagram for palmmeteo_stdplugins.meteo.RequiresMeteoPluginMixin:
[legend]

## Public Member Functions
| __init__ (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.Plugin
| check_config (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.PluginMeta
| __new__ (cls, name, bases, dct)

## Public Attributes
| Requires

## Detailed Description

    Set a list of required meteorological variables in plugin metainformation:

    class Requires:
        meteo_vars = [ ... ]

    Global available_meteo_vars holds names of all variables known to the
    processor.

## Constructor & Destructor Documentation

## ◆ __init__()

palmmeteo_stdplugins.meteo.RequiresMeteoPluginMixin.__init__ | ( |  | self,
|  | * | args,
|  | ** | kwargs
| ) |  |

## Member Data Documentation

## ◆ Requires

palmmeteo_stdplugins.meteo.RequiresMeteoPluginMixin.Requires

The documentation for this class was generated from the following file:

- palmmeteo_stdplugins/meteo.py